Struct RawCallResult
pub struct RawCallResult<FEN = EthEvmNetwork>where
FEN: FoundryEvmNetwork,{Show 20 fields
pub exit_reason: Option<InstructionResult>,
pub reverted: bool,
pub has_state_snapshot_failure: bool,
pub result: Bytes,
pub gas_used: u64,
pub gas_refunded: u64,
pub stipend: u64,
pub logs: Vec<Log>,
pub labels: HashMap<Address, String, FbBuildHasher<20>>,
pub traces: Option<SparsedTraceArena>,
pub line_coverage: Option<HitMaps>,
pub edge_coverage: Option<Vec<u8>>,
pub transactions: Option<VecDeque<BroadcastableTransaction<<FEN as FoundryEvmNetwork>::Network>>>,
pub state_changeset: HashMap<Address, Account, FbBuildHasher<20>>,
pub evm_env: EvmEnv<<<FEN as FoundryEvmNetwork>::EvmFactory as EvmFactory>::Spec, <<FEN as FoundryEvmNetwork>::EvmFactory as EvmFactory>::BlockEnv>,
pub tx_env: <<FEN as FoundryEvmNetwork>::EvmFactory as EvmFactory>::Tx,
pub cheatcodes: Option<Box<Cheatcodes<FEN>>>,
pub out: Option<Output>,
pub chisel_state: Option<(Vec<Uint<256, 4>>, Vec<u8>)>,
pub reverter: Option<Address>,
}Expand description
The result of a raw call.
Fields
exit_reason: Option<InstructionResult>The status of the call
reverted: boolWhether the call reverted or not
has_state_snapshot_failure: boolWhether the call includes a snapshot failure
This is tracked separately from revert because a snapshot failure can occur without a revert, since assert failures are stored in a global variable (ds-test legacy)
result: BytesThe raw result of the call.
gas_used: u64The gas used for the call
gas_refunded: u64Refunded gas
stipend: u64The initial gas stipend for the transaction
logs: Vec<Log>The logs emitted during the call
labels: HashMap<Address, String, FbBuildHasher<20>>The labels assigned to addresses during the call
traces: Option<SparsedTraceArena>The traces of the call
line_coverage: Option<HitMaps>The line coverage info collected during the call
edge_coverage: Option<Vec<u8>>The edge coverage info collected during the call
transactions: Option<VecDeque<BroadcastableTransaction<<FEN as FoundryEvmNetwork>::Network>>>Scripted transactions generated from this call
state_changeset: HashMap<Address, Account, FbBuildHasher<20>>The changeset of the state.
evm_env: EvmEnv<<<FEN as FoundryEvmNetwork>::EvmFactory as EvmFactory>::Spec, <<FEN as FoundryEvmNetwork>::EvmFactory as EvmFactory>::BlockEnv>The EvmEnv after the call
tx_env: <<FEN as FoundryEvmNetwork>::EvmFactory as EvmFactory>::TxThe TxEnv after the call
cheatcodes: Option<Box<Cheatcodes<FEN>>>The cheatcode states after execution
out: Option<Output>The raw output of the execution
chisel_state: Option<(Vec<Uint<256, 4>>, Vec<u8>)>The chisel state
reverter: Option<Address>Implementations
impl<FEN> RawCallResult<FEN>where
FEN: FoundryEvmNetwork,
impl<FEN> RawCallResult<FEN>where
FEN: FoundryEvmNetwork,
pub fn from_evm_result(
r: Result<RawCallResult<FEN>, EvmError<FEN>>,
) -> Result<(RawCallResult<FEN>, Option<String>), Report>
pub fn from_evm_result( r: Result<RawCallResult<FEN>, EvmError<FEN>>, ) -> Result<(RawCallResult<FEN>, Option<String>), Report>
Unpacks an EVM result.
pub fn into_evm_error(self, rd: Option<&RevertDecoder>) -> EvmError<FEN>
pub fn into_evm_error(self, rd: Option<&RevertDecoder>) -> EvmError<FEN>
Converts the result of the call into an EvmError.
pub fn into_execution_error(self, reason: String) -> ExecutionErr<FEN>
pub fn into_execution_error(self, reason: String) -> ExecutionErr<FEN>
Converts the result of the call into an ExecutionErr.
pub fn into_result(
self,
rd: Option<&RevertDecoder>,
) -> Result<RawCallResult<FEN>, EvmError<FEN>>
pub fn into_result( self, rd: Option<&RevertDecoder>, ) -> Result<RawCallResult<FEN>, EvmError<FEN>>
Returns an EvmError if the call failed, otherwise returns self.
pub fn into_decoded_result(
self,
func: &Function,
rd: Option<&RevertDecoder>,
) -> Result<CallResult<DynSolValue, FEN>, EvmError<FEN>>
pub fn into_decoded_result( self, func: &Function, rd: Option<&RevertDecoder>, ) -> Result<CallResult<DynSolValue, FEN>, EvmError<FEN>>
Decodes the result of the call with the given function.
pub fn transactions(
&self,
) -> Option<&VecDeque<BroadcastableTransaction<<FEN as FoundryEvmNetwork>::Network>>>
pub fn transactions( &self, ) -> Option<&VecDeque<BroadcastableTransaction<<FEN as FoundryEvmNetwork>::Network>>>
Returns the transactions generated from this call.
pub fn merge_edge_coverage(&mut self, history_map: &mut [u8]) -> (bool, bool)
pub fn merge_edge_coverage(&mut self, history_map: &mut [u8]) -> (bool, bool)
Update provided history map with edge coverage info collected during this call. Uses AFL binning algo https://github.com/h0mbre/Lucid/blob/3026e7323c52b30b3cf12563954ac1eaa9c6981e/src/coverage.rs#L57-L85